# PyVista-GUI

A plug 'n' play framework for building commercial-grade applications built on
top of PyVista. This module makes it simple to build (and prototype) an
application for processing and visualizing 3D data.

## Disclaimer

This is currently a work in progress - things will break and change!


## Get Started

To launch, simply run:

```bash
python -m pyvista_gui
```
